#!/usr/bin/env pythonw

import os, platform, sys
import Config
from lib import logger

if __name__ == '__main__':
    if platform.system() != 'Windows':
        import os
        os.putenv('PATH', os.getenv('PATH') + ':/usr/local/bin')
    
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option('-v', '--verbose', dest='verbosity', action='count', default=0, help='Verbose logging')
    parser.add_option('-e', '--execute', dest='tool', default='', help='Run specified tool (syntax plugin.toolname)', metavar='plugin.tool')
    parser.add_option('-u', '--interface', dest='ui', default='wxw', help='Specify which UI to use (default wxw)', metavar='name')
    if not hasattr(sys, 'frozen'):
        parser.add_option('-a', '--appcast', dest='appcast', default=None, help='Specify an appcast URL', metavar='URL')
    (options, args) = parser.parse_args()
    Config.Invocation.options = options
    Config.Invocation.args = args
    
    import ui
    ui.setup(options.ui)
    from ui import App
    logger.init(options.verbosity)
    app = App.App()
    import RemoteEditor
    RemoteEditor.setup()
    app.MainLoop()
    RemoteEditor.teardown()
    import Connection
    Connection.teardown()
    import gc
    if len(gc.garbage):
        logger.log('Garbage found - %d items' % (len(gc.garbage,)), logger.DEBUG)
        logger.log_object(gc.get_referrers(*gc.garbage), logger.DEBUG)
        logger.log_object(gc.get_referents(*gc.garbage), logger.DEBUG)
    logger.log = lambda *args: None
